## :blush: Welcome to the PyPSSE Repository

> A python wrapper around psspy (python API for PSSE simulator) to perform
> time series powerflow and dynamic simulation for power system fault

### :email: Contact Information
* :snowman: [Aadil Latif](mailto:aadil.latif@nrel.gov)
* :snowman: [Kapil Duwadi](mailto:kapil.duwadi@nrel.gov)

###

For usage guidance, pleae see [PyPSSE documentation](https://NREL.github.io/PyPSSE/)
